/////////////////////////////////////////////
//      Network Security Analysis Tool     //
//           (c) 1999 by Mixter            //
//                                         //
// well-known port and rpc service numbers //
/////////////////////////////////////////////

#ifndef SERVICES_H
#define SERVICES_H

#define S_TCPMUX	1
#define S_ECHO		7
#define S_NSTAT		15
#define S_CGEN		19
#define S_FTP		21
#define S_SSH		22
#define S_TELNET	23
#define S_SMTP		25
#define S_WHOIS		43
#define S_BIND		53
#define S_LCONF		98
#define S_FINGER	79
#define S_HTTP		80
#define S_POP2		109
#define S_POP3		110
#define S_PMAP		111
#define S_NNTP		119
#define S_SMB		139
#define S_IMAP		143
#define S_FW1		261
#define S_REXEC		512
#define S_RLOGIN	513
#define S_RSH		514
#define S_LP		515
#define S_BD666		666
#define S_SOCKS		1080
#define S_MSQL		1114
#define S_BD1524	1524
#define S_ORACLE	1525
#define S_NLPS		2766
#define S_IRCD		6667
#define S_XWIN		6000
#define S_PROXY		8080
#define S_BDTRINOO	27665
#define SU_NBNAME	137
#define SU_NFS		2049
#define SU_BO		31337
#define R_STATD		100001
#define R_NFS		100003
#define R_YPSERV	100004
#define R_MOUNTD	100005
#define R_WALLD		100008
#define R_NLOCK		100021
#define R_STATUS	100024
#define R_BOOTPD	100026
#define R_TTDB		100083
#define R_CMSD		100086
#define R_LISTEN	100099
#define R_SADMIND	100232
#define R_NIS		100300
#define R_AMD		300019

#endif
